import requests

class Orders():
    def __init__(self, Authorization, URL, Headers):
        self.Authorization = Authorization
        self.URL = URL
        self.Headers = Headers

    def FetchAll(self):
        return requests.get(self.URL + "/orders", headers=self.Headers).json()



from .Orders import *

__Name__ = "Sellix"
__Author__ = "xFueY"
__AuthorMail__ = "xFueY@protonmail.com"
__Version__ = "0.0.1_1"
__Description__ = "Python Sellix Wrapper"
__URL__ = "https://github.com/xFueY/Sellix/"
__License__ = "MIT"

class Sellix():
    def __init__(self, Authorization : str, URL : str = "https://dev.sellix.io/v1"):
        self.Authorization = Authorization
        self.URL = URL
        self.Headers = {"Authorization" : f"Bearer {Authorization}", "User-Agent" : f"Python Sellix v{__Version__}"}

        self.Orders = Orders(self.Authorization, self.URL, self.Headers)



from setuptools import setup, find_packages
import Sellix

Classifiers = [
  "Development Status :: 5 - Production/Stable",
  "Intended Audience :: Developers",
  "License :: OSI Approved :: MIT License",
  "Natural Language :: English",
  "Programming Language :: Python :: 3.8"
]

setup(
  name=Sellix.__Name__,
  version=Sellix.__Version__,
  description=Sellix.__Description__,
  long_description=open('README.md').read(),
  long_description_content_type="text/markdown",
  url=Sellix.__URL__,
  author=Sellix.__Author__,
  author_email=Sellix.__AuthorMail__,
  license=Sellix.__License__,
  classifiers=Classifiers,
  packages=find_packages(),
  keywords="Sellix",
  install_requires=["requests"]
)
